# Migrating to the TBM Taxonomy Version 5.0.1 for Tech Categories
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/migrating-to-tbm-taxonomy-version-5-0-1-for-tech-categories#overview)
  * [Step 1: Update the Tech Category Hierarchy](https://help.sap.com/docs/leanix/ea/migrating-to-tbm-taxonomy-version-5-0-1-for-tech-categories#step-1:-update-the-tech-category-hierarchy)
  * [Step 2: Rename Tech Categories](https://help.sap.com/docs/leanix/ea/migrating-to-tbm-taxonomy-version-5-0-1-for-tech-categories#step-2:-rename-tech-categories)
  * [Step 3: Import and Link Tech Categories](https://help.sap.com/docs/leanix/ea/migrating-to-tbm-taxonomy-version-5-0-1-for-tech-categories#step-3:-import-and-link-tech-categories)
  * [Step 4: Update Relations to IT Components](https://help.sap.com/docs/leanix/ea/migrating-to-tbm-taxonomy-version-5-0-1-for-tech-categories#step-4:-update-relations-to-it-components)
  * [Step 5: Clean Up Your Workspace](https://help.sap.com/docs/leanix/ea/migrating-to-tbm-taxonomy-version-5-0-1-for-tech-categories#step-5:-clean-up-your-workspace)


Migrate to the TBM Taxonomy version 5.0.1 to keep your tech categories in sync with the latest version.
